LedgerUsb class

Constructors

LedgerUsb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<bool>
exchange(List<Uint8List> apdus, {int timeout = 2000}) → Future<List<Uint8List>>
listDevices() → Future<List<UsbDevice>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(UsbDevice usbDevice) → Future<bool>
requestPermission(UsbDevice usbDevice) → Future<bool>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited