ResponseAcc class

Constructors

ResponseAcc({required Uint8List data, required int length, required int sequence})

Properties

data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited