WebLedgerUsb class

Inheritance

Constructors

WebLedgerUsb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<bool>
override
getDevices() → Future<List<UsbDevice>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(UsbDevice usbDevice) → Future<bool>
override
requestPermission(UsbDevice usbDevice) → Future<bool>
override
toString() → String
A string representation of this object.
inherited
transferIn(int packetSize, int timeout) → Future<Uint8List?>
override
transferOut(Uint8List data, int timeout) → Future<int>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited